@@ -20,7 +20,7 @@ from .util import Print, VERBOSITY, Preproc as Pp
 from functools import reduce
 from six.moves import xrange
 
-__version__ = "0.5.3"
+__version__ = "0.5.4"
 
 ENCODING = "utf-8"
 
@@ -1806,7 +1806,7 @@ class SS3:
         Print.info("learning...", offset=1)
         tips = []
         for word in doc:
-            if word != ".":
+            if word and word != '.':
                 self.__prun_counter__ += 1
                 # if word doesn't exist yet, then...
                 try:
